@@ -5,6 +5,9 @@
 #define XXXXXXX    0
 #define USE_PENALTY_EX  1
 
+#define TERMGAPFAC 0.0
+#define TERMGAPFAC_EX 0.0
+
 #if 1
 static void match_calc_mtx( double **mtx, double *match, char **s1, char **s2, int i1, int lgth2 ) 
 {
@@ -37,7 +40,9 @@ static double Atracking( double *lasthorizontalw, double *lastverticalw,
 	gap = newgapstr;
 	lgth1 = strlen( seq1[0] );
 	lgth2 = strlen( seq2[0] );
-	double wm;
+	double wm, g;
+	double fpenalty = (double)penalty;
+	double fpenalty_ex = (double)penalty_ex;
 
 
 #if 0
@@ -56,11 +61,41 @@ static double Atracking( double *lasthorizontalw, double *lastverticalw,
         ijp[0][j] = -( j + 1 );
     }
 
+
 //	if( tailgp == 1 || ijp[lgth1][lgth2] >= warpbase )
 	if( tailgp == 1 )
 		;
 	else
 	{
+#if 1
+//		reporterr( "lastverticalw[lgth1-1] = %f\n", lastverticalw[lgth1-1] );
+//		reporterr( "lasthorizontalw[lgth2-1] = %f\n", lasthorizontalw[lgth2-1] );
+		wm = lasthorizontalw[lgth2-1] - 1.0; // lasthorizontalw[lgth2-1] yori kanarazu chiisai.
+		for( j=lgth2-2; j>=0; j-- )
+		{
+			if( (g=lasthorizontalw[j]+ ( fpenalty * TERMGAPFAC + fpenalty_ex * (lgth2-1-j) * TERMGAPFAC_EX ) ) > wm )
+			{
+				wm = g;
+				iin = lgth1-1; jin = j;
+				ijp[lgth1][lgth2] = -( lgth2 - j );
+			}
+		}
+		for( i=lgth1-2; i>=0; i-- )
+		{
+			if( ( g=lastverticalw[i]+ ( fpenalty * TERMGAPFAC + fpenalty_ex * (lgth1-1-i) * TERMGAPFAC_EX ) ) > wm )
+			{
+				wm = g;
+				iin = i; jin = lgth2-1;
+				ijp[lgth1][lgth2] = +( lgth1 - i );
+			}
+		}
+		if( lasthorizontalw[lgth2-1] > wm )  // score ga onaji baai erabarenai
+		{
+			wm = lasthorizontalw[lgth2-1];
+			iin = lgth1-1; jin = lgth2-1;
+			ijp[lgth1][lgth2] = 0;
+		}
+#else
 		wm = lastverticalw[0];
 		for( i=0; i<lgth1; i++ )
 		{
@@ -80,6 +115,7 @@ static double Atracking( double *lasthorizontalw, double *lastverticalw,
 				ijp[lgth1][lgth2] = -( lgth2 - j );
 			}
 		}
+#endif
 	}
 
 
@@ -158,19 +194,20 @@ static double Atracking( double *lasthorizontalw, double *lastverticalw,
 
 //	fprintf( stderr, "%s\n", mseq1[0] );
 //	fprintf( stderr, "%s\n", mseq2[0] );
-	return( 0.0 );
+	return( wm );
 }
 
 
 double G__align11( double **n_dynamicmtx, char **seq1, char **seq2, int alloclen, int headgp, int tailgp )
 {
+
 //	int k;
 	register int i, j;
 	int lasti;                      /* outgap == 0 -> lgth1, outgap == 1 -> lgth1+1 */
 	int lastj;
 	int lgth1, lgth2;
 	int resultlen;
-	double wm;   /* int ?????? */
+	double wm, wmo;   /* int ?????? */
 	double g;
 	double *currentw, *previousw;
 	double fpenalty = (double)penalty;
@@ -178,6 +215,7 @@ double G__align11( double **n_dynamicmtx, char **seq1, char **seq2, int alloclen
 	double fpenalty_tmp;
 #if USE_PENALTY_EX
 	double fpenalty_ex = (double)penalty_ex;
+	double fpenalty_ex_i;
 #endif
 #if 1
 	double *wtmp;
@@ -428,12 +466,40 @@ double G__align11( double **n_dynamicmtx, char **seq1, char **seq2, int alloclen
 		for( i=1; i<lgth1+1; i++ )
 		{
 			initverticalw[i] += fpenalty;
+#if USE_PENALTY_EX
+//			initverticalw[i] += fpenalty_ex * i; // ato de fukkatsu
+//			reporterr( "added _ex\n" );
+#endif
 		}
 		for( j=1; j<lgth2+1; j++ )
 		{
 			currentw[j] += fpenalty;
+#if USE_PENALTY_EX
+//			currentw[j] += fpenalty_ex * j; // ato de fukkatsu
+//			reporterr( "added _ex\n" );
+#endif
 		}
 	}
+	else
+	{
+		for( i=1; i<lgth1+1; i++ )
+		{
+			initverticalw[i] += fpenalty * TERMGAPFAC;
+#if USE_PENALTY_EX // 2018/Apr/22
+			initverticalw[i] += fpenalty_ex * i * TERMGAPFAC_EX;
+//			reporterr( "added _ex\n" );
+#endif
+		}
+		for( j=1; j<lgth2+1; j++ )
+		{
+			currentw[j] += fpenalty * TERMGAPFAC;
+#if USE_PENALTY_EX // 2018/Apr/22
+			currentw[j] += fpenalty_ex * j * TERMGAPFAC_EX;
+//			reporterr( "added _ex\n" );
+#endif
+		}
+	}
+
 
 	for( j=1; j<lgth2+1; ++j ) 
 	{
@@ -510,6 +576,9 @@ fprintf( stderr, "\n" );
 			warpjpt = warpj + 1;
 		}
 
+		if( i < lgth1 ) fpenalty_ex_i = fpenalty_ex;
+		else fpenalty_ex_i = 0.0; // 2018/May/11
+
 		for( j=1; j<lastj; j++ )
 		{
 
@@ -528,12 +597,14 @@ fprintf( stderr, "\n" );
 				*ijppt = -( j - mpi );
 			}
 			if( (g=*prept) >= mi )
+//			if( (g=*prept) > mi )
 			{
 				mi = g;
 				mpi = j-1;
 			}
 #if USE_PENALTY_EX
-			mi += fpenalty_ex;
+			mi += fpenalty_ex_i;
+//			mi += fpenalty_ex;
 #endif
 
 #if 0 
@@ -545,12 +616,14 @@ fprintf( stderr, "\n" );
 				*ijppt = +( i - *mpjpt );
 			}
 			if( (g=*prept) >= *mjpt )
+//			if( (g=*prept) > *mjpt )
 			{
 				*mjpt = g;
 				*mpjpt = i-1;
 			}
 #if USE_PENALTY_EX
-			m[j] += fpenalty_ex;
+			if( j < lgth2 ) // 2018/May/11
+				m[j] += fpenalty_ex;
 #endif
 #if 1
 			if( trywarp )
@@ -647,6 +720,7 @@ fprintf( stderr, "\n" );
 		}
 	}
 
+
 	if( trywarp )
 	{
 //		fprintf( stderr, "\nwm = %f\n", wm );
@@ -659,7 +733,10 @@ fprintf( stderr, "\n" );
 		free( prevwarpj );
 	}
 
-	Atracking( currentw, lastverticalw, seq1, seq2, mseq1, mseq2, ijp, tailgp, warpis, warpjs, warpbase );
+	wmo = Atracking( currentw, lastverticalw, seq1, seq2, mseq1, mseq2, ijp, tailgp, warpis, warpjs, warpbase );
+	if( !tailgp ) wm = wmo;
+
+//	reporterr( "wm (after tracking) = %f\n", wm );
 	if( warpis ) free( warpis );
 	if( warpjs ) free( warpjs );
 
@@ -698,6 +775,7 @@ double G__align11_noalign( double **n_dynamicmtx, int penal, int penal_ex, char
 	double fpenalty = (double)penal;
 #if USE_PENALTY_EX
 	double fpenalty_ex = (double)penal_ex;
+	double fpenalty_ex_i;
 #endif
 #if 1
 	double *wtmp;
@@ -797,7 +875,8 @@ double G__align11_noalign( double **n_dynamicmtx, int penal, int penal_ex, char
 		intwork = AllocateIntMtx( nalphabets, MAX( ll1, ll2 )+2 ); 
 
 
-		amino_dynamicmtx = AllocateDoubleMtx( 0x80, 0x80 );
+//		amino_dynamicmtx = AllocateDoubleMtx( 0x80, 0x80 ); 
+		amino_dynamicmtx = AllocateDoubleMtx( 0x100, 0x100 );  // 2017/Nov.  constants.c no 'charsize' wo global hensuu nishita houga yoi?
 #if DEBUG
 		fprintf( stderr, "succeeded\n" );
 #endif
@@ -811,8 +890,6 @@ double G__align11_noalign( double **n_dynamicmtx, int penal, int penal_ex, char
 		amino_dynamicmtx[(int)amino[i]][(int)amino[j]] = (double)n_dynamicmtx[i][j];
 
 
-
-
 #if 0
 	for( i=0; i<lgth1; i++ ) 
 		fprintf( stderr, "ogcp1[%d]=%f\n", i, ogcp1[i] );
@@ -832,10 +909,18 @@ double G__align11_noalign( double **n_dynamicmtx, int penal, int penal_ex, char
 		for( i=1; i<lgth1+1; i++ )
 		{
 			initverticalw[i] += fpenalty;
+#if USE_PENALTY_EX // 2018/Apr/23
+//			initverticalw[i] += fpenalty_ex * i; // ato de fukkatsu
+//			reporterr( "added _ex\n" );
+#endif
 		}
 		for( j=1; j<lgth2+1; j++ )
 		{
 			currentw[j] += fpenalty;
+#if USE_PENALTY_EX // 2018/Apr/23
+//			currentw[j] += fpenalty_ex * j; // ato de fukkatsu
+//			reporterr( "added _ex\n" );
+#endif
 		}
 	}
 
@@ -902,6 +987,10 @@ fprintf( stderr, "\n" );
 		mjpt = m + 1;
 		prept = previousw;
 		curpt = currentw + 1;
+
+		if( i < lgth1 ) fpenalty_ex_i = fpenalty_ex;
+		else fpenalty_ex_i = 0.0; // 2018/May/11
+
 		for( j=1; j<lgth2+1; j++ )
 		{
 			wm = *prept;
@@ -916,12 +1005,13 @@ fprintf( stderr, "\n" );
 			{
 				wm = g;
 			}
-			if( (g=*prept) >= mi )
+//			if( (g=*prept) >= mi )
+			if( (g=*prept) > mi ) // onaji hazu
 			{
 				mi = g;
 			}
 #if USE_PENALTY_EX
-			mi += fpenalty_ex;
+			mi += fpenalty_ex_i;
 #endif
 
 #if 0 
@@ -931,12 +1021,14 @@ fprintf( stderr, "\n" );
 			{
 				wm = g;
 			}
-			if( (g=*prept) >= *mjpt )
+//			if( (g=*prept) >= *mjpt )
+			if( (g=*prept) > *mjpt ) // onaji hazu
 			{
 				*mjpt = g;
 			}
 #if USE_PENALTY_EX
-			m[j] += fpenalty_ex;
+			if( j < lgth2 ) // 2018/May/11
+				m[j] += fpenalty_ex;
 #endif
 
 #if 0
@@ -953,7 +1045,7 @@ fprintf( stderr, "\n" );
 	fprintf( stderr, "\n" );
 	fprintf( stderr, ">\n%s\n", mseq1[0] );
 	fprintf( stderr, ">\n%s\n", mseq2[0] );
-	fprintf( stderr, "wm = %f\n", wm );
+	fprintf( stderr, "wm (noalign) = %f\n", wm );
 #endif
 
 	return( wm );
