@@ -13,17 +13,17 @@
 
 static int reccycle = 0;
 
-static float localthr;
+static double localthr;
 
-static void match_ribosum( float *match, float **cpmx1, float **cpmx2, int i1, int lgth2, float **floatwork, int **intwork, int initialize )
+static void match_ribosum( double *match, double **cpmx1, double **cpmx2, int i1, int lgth2, double **doublework, int **intwork, int initialize )
 {
 	int j, k, l;
-	float scarr[38];
-	float **cpmxpd = floatwork;
+	double scarr[38];
+	double **cpmxpd = doublework;
 	int **cpmxpdn = intwork;
 	int count = 0;
-	float *matchpt;
-	float **cpmxpdpt;
+	double *matchpt;
+	double **cpmxpdpt;
 	int **cpmxpdnpt;
 	int cpkd;
 
@@ -53,9 +53,9 @@ static void match_ribosum( float *match, float **cpmx1, float **cpmx2, int i1, i
 			scarr[l] += ribosumdis[k][l] * cpmx1[i1][k];
 		}
 	}
-#if 0 /* ȤȤfloatworkΥȤդˤ */
+#if 0 /* ȤȤdoubleworkΥȤդˤ */
 	{
-		float *fpt, **fptpt, *fpt2;
+		double *fpt, **fptpt, *fpt2;
 		int *ipt, **iptpt;
 		fpt2 = match;
 		iptpt = cpmxpdn;
@@ -91,19 +91,19 @@ static void match_ribosum( float *match, float **cpmx1, float **cpmx2, int i1, i
 #endif
 }
 
-static void match_calc( float *match, float **cpmx1, float **cpmx2, int i1, int lgth2, float **floatwork, int **intwork, int initialize )
+static void match_calc( double *match, double **cpmx1, double **cpmx2, int i1, int lgth2, double **doublework, int **intwork, int initialize )
 {
 	int j, k, l;
-//	float scarr[26];
-	float **cpmxpd = floatwork;
+//	double scarr[26];
+	double **cpmxpd = doublework;
 	int **cpmxpdn = intwork;
 	int count = 0;
-	float *matchpt;
-	float **cpmxpdpt;
+	double *matchpt;
+	double **cpmxpdpt;
 	int **cpmxpdnpt;
 	int cpkd;
-	float *scarr;
-	scarr = calloc( nalphabets, sizeof( float ) );
+	double *scarr;
+	scarr = calloc( nalphabets, sizeof( double ) );
 
 	if( initialize )
 	{
@@ -131,9 +131,9 @@ static void match_calc( float *match, float **cpmx1, float **cpmx2, int i1, int
 			scarr[l] += (n_dis[k][l]-RNAthr) * cpmx1[i1][k];
 		}
 	}
-#if 0 /* ȤȤfloatworkΥȤդˤ */
+#if 0 /* ȤȤdoubleworkΥȤդˤ */
 	{
-		float *fpt, **fptpt, *fpt2;
+		double *fpt, **fptpt, *fpt2;
 		int *ipt, **iptpt;
 		fpt2 = match;
 		iptpt = cpmxpdn;
@@ -171,15 +171,15 @@ static void match_calc( float *match, float **cpmx1, float **cpmx2, int i1, int
 }
 
 #if 0
-static void match_add( float *match, float **cpmx1, float **cpmx2, int i1, int lgth2, float **floatwork, int **intwork, int initialize )
+static void match_add( double *match, double **cpmx1, double **cpmx2, int i1, int lgth2, double **doublework, int **intwork, int initialize )
 {
 	int j, k, l;
-	float scarr[nalphabets];
-	float **cpmxpd = floatwork;
+	double scarr[nalphabets];
+	double **cpmxpd = doublework;
 	int **cpmxpdn = intwork;
 	int count = 0;
-	float *matchpt;
-	float **cpmxpdpt;
+	double *matchpt;
+	double **cpmxpdpt;
 	int **cpmxpdnpt;
 	int cpkd;
 
@@ -210,9 +210,9 @@ static void match_add( float *match, float **cpmx1, float **cpmx2, int i1, int l
 			scarr[l] += n_dis[k][l] * cpmx1[i1][k];
 		}
 	}
-#if 0 /* ȤȤfloatworkΥȤդˤ */
+#if 0 /* ȤȤdoubleworkΥȤդˤ */
 	{
-		float *fpt, **fptpt, *fpt2;
+		double *fpt, **fptpt, *fpt2;
 		int *ipt, **iptpt;
 		fpt2 = match;
 		iptpt = cpmxpdn;
@@ -250,7 +250,7 @@ static void match_add( float *match, float **cpmx1, float **cpmx2, int i1, int l
 #endif
 
 #if 0
-static float Atracking( 
+static double Atracking( 
 						char **seq1, char **seq2, 
                         char **mseq1, char **mseq2, 
                         int **ijp, int icyc, int jcyc,
@@ -343,46 +343,46 @@ static float Atracking(
 #endif
 
 
-static float MSalign2m2m_rec( int icyc, int jcyc, double *eff1, double *eff2, char **seq1, char **seq2, float **cpmx1, float **cpmx2, int ist, int ien, int jst, int jen, int alloclen, char **mseq1, char **mseq2, int depth, float **gapinfo, float **map )
+static double MSalign2m2m_rec( int icyc, int jcyc, double *eff1, double *eff2, char **seq1, char **seq2, double **cpmx1, double **cpmx2, int ist, int ien, int jst, int jen, int alloclen, char **mseq1, char **mseq2, int depth, double **gapinfo, double **map )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
-	float value = 0.0;
+	double value = 0.0;
 	register int i, j;
 	char **aseq1, **aseq2;
 	int ll1, ll2;
 	int lasti, lastj, imid, jmid = 0;
-	float wm = 0.0;   /* int ?????? */
-	float g;
-	float *currentw, *previousw;
+	double wm = 0.0;   /* int ?????? */
+	double g;
+	double *currentw, *previousw;
 #if USE_PENALTY_EX
-	float fpenalty_ex = (float)penalty_ex;
+	double fpenalty_ex = (double)penalty_ex;
 #endif
-//	float fpenalty = (float)penalty;
-	float *wtmp;
+//	double fpenalty = (double)penalty;
+	double *wtmp;
 //	short *ijppt;
 	int *mpjpt;
 //	short **ijp;
 	int *mp;
 	int mpi;
-	float *mjpt, *prept, *curpt;
-	float mi;
-	float *m;
-	float *w1, *w2;
-//	float *match;
-	float *initverticalw;    /* kufuu sureba iranai */
-	float *lastverticalw;    /* kufuu sureba iranai */
+	double *mjpt, *prept, *curpt;
+	double mi;
+	double *m;
+	double *w1, *w2;
+//	double *match;
+	double *initverticalw;    /* kufuu sureba iranai */
+	double *lastverticalw;    /* kufuu sureba iranai */
 	int **intwork;
-	float **floatwork;
+	double **doublework;
 //	short **shortmtx;
 #if STOREWM
-	float **WMMTX;
-	float **WMMTX2;
+	double **WMMTX;
+	double **WMMTX2;
 #endif
-	float *midw;
-	float *midm;
-	float *midn;
+	double *midw;
+	double *midm;
+	double *midn;
 	int lgth1, lgth2;
-	float maxwm = 0.0;
+	double maxwm = 0.0;
 	int *jumpforwi;
 	int *jumpforwj;
 	int *jumpbacki;
@@ -392,11 +392,11 @@ static float MSalign2m2m_rec( int icyc, int jcyc, double *eff1, double *eff2, ch
 	int jumpi, jumpj = 0;
 	char *gaps;
 	int ijpi, ijpj;
-	float *ogcp1;
-	float *fgcp1;
-	float *ogcp2;
-	float *fgcp2;
-	float firstm;
+	double *ogcp1;
+	double *fgcp1;
+	double *ogcp2;
+	double *fgcp2;
+	double firstm;
 	int firstmp;
 #if 0
 	static char ttt1[50000];
@@ -514,7 +514,7 @@ static float MSalign2m2m_rec( int icyc, int jcyc, double *eff1, double *eff2, ch
 	mp = AllocateIntVec( ll2+2 );
 	gaps = AllocateCharVec( MAX( ll1, ll2 ) + 2 );
 
-	floatwork = AllocateFloatMtx( MAX( ll1, ll2 )+2, nalphabets ); 
+	doublework = AllocateFloatMtx( MAX( ll1, ll2 )+2, nalphabets ); 
 	intwork = AllocateIntMtx( MAX( ll1, ll2 )+2, nalphabets ); 
 
 #if DEBUG
@@ -538,9 +538,9 @@ static float MSalign2m2m_rec( int icyc, int jcyc, double *eff1, double *eff2, ch
 	currentw = w1;
 	previousw = w2;
 
-	match_ribosum( initverticalw, cpmx2+jst, cpmx1+ist, 0, lgth1, floatwork, intwork, 1 );
+	match_ribosum( initverticalw, cpmx2+jst, cpmx1+ist, 0, lgth1, doublework, intwork, 1 );
 
-	match_ribosum( currentw, cpmx1+ist, cpmx2+jst, 0, lgth2, floatwork, intwork, 1 );
+	match_ribosum( currentw, cpmx1+ist, cpmx2+jst, 0, lgth2, doublework, intwork, 1 );
 
 	for( i=1; i<lgth1+1; i++ )
 	{
@@ -589,7 +589,7 @@ static float MSalign2m2m_rec( int icyc, int jcyc, double *eff1, double *eff2, ch
 
 		previousw[0] = initverticalw[i-1];
 
-		match_ribosum( currentw, cpmx1+ist, cpmx2+jst, i, lgth2, floatwork, intwork, 0 );
+		match_ribosum( currentw, cpmx1+ist, cpmx2+jst, i, lgth2, doublework, intwork, 0 );
 		currentw[0] = initverticalw[i];
 
 		m[0] = ogcp1[i];
@@ -740,8 +740,8 @@ static float MSalign2m2m_rec( int icyc, int jcyc, double *eff1, double *eff2, ch
 
 // gyakudp
 
-	match_ribosum( initverticalw, cpmx2+jst, cpmx1+ist, lgth2-1, lgth1, floatwork, intwork, 1 );
-	match_ribosum( currentw, cpmx1+ist, cpmx2+jst, lgth1-1, lgth2, floatwork, intwork, 1 );
+	match_ribosum( initverticalw, cpmx2+jst, cpmx1+ist, lgth2-1, lgth1, doublework, intwork, 1 );
+	match_ribosum( currentw, cpmx1+ist, cpmx2+jst, lgth1-1, lgth2, doublework, intwork, 1 );
 
 	for( i=0; i<lgth1-1; i++ )
 	{
@@ -793,7 +793,7 @@ static float MSalign2m2m_rec( int icyc, int jcyc, double *eff1, double *eff2, ch
 		currentw = wtmp;
 		previousw[lgth2-1] = initverticalw[i+1];
 //		match_calc( currentw, seq1, seq2, i, lgth2 );
-		match_ribosum( currentw, cpmx1+ist, cpmx2+jst, i, lgth2, floatwork, intwork, 0 );
+		match_ribosum( currentw, cpmx1+ist, cpmx2+jst, i, lgth2, doublework, intwork, 0 );
 
 		currentw[lgth2-1] = initverticalw[i];
 
@@ -1057,8 +1057,8 @@ static float MSalign2m2m_rec( int icyc, int jcyc, double *eff1, double *eff2, ch
 #if 0
 	for( i=0; i<lgth1; i++ )
 	{
-		float maxpairscore = -9999.9;
-		float tmpscore;
+		double maxpairscore = -9999.9;
+		double tmpscore;
 
 		for( j=0; j<lgth2; j++ )
 		{
@@ -1085,8 +1085,8 @@ static float MSalign2m2m_rec( int icyc, int jcyc, double *eff1, double *eff2, ch
 	}
 	for( j=0; j<lgth2; j++ )
 	{
-		float maxpairscore = -9999.9;
-		float tmpscore;
+		double maxpairscore = -9999.9;
+		double tmpscore;
 
 		for( i=0; i<lgth1; i++ )
 		{
@@ -1232,7 +1232,7 @@ static float MSalign2m2m_rec( int icyc, int jcyc, double *eff1, double *eff2, ch
 	FreeFloatVec( m );
 	FreeIntVec( mp );
 
-	FreeFloatMtx( floatwork );
+	FreeFloatMtx( doublework );
 	FreeIntMtx( intwork );
 
 #if STOREWM
@@ -1243,46 +1243,46 @@ static float MSalign2m2m_rec( int icyc, int jcyc, double *eff1, double *eff2, ch
 	return( value );
 
 }
-static float MSalignmm_rec( int icyc, int jcyc, double *eff1, double *eff2, char **seq1, char **seq2, float **cpmx1, float **cpmx2, int ist, int ien, int jst, int jen, int alloclen, char **mseq1, char **mseq2, int depth, float **gapinfo, float **map )
+static double MSalignmm_rec( int icyc, int jcyc, double *eff1, double *eff2, char **seq1, char **seq2, double **cpmx1, double **cpmx2, int ist, int ien, int jst, int jen, int alloclen, char **mseq1, char **mseq2, int depth, double **gapinfo, double **map )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
-	float value = 0.0;
+	double value = 0.0;
 	register int i, j;
 	char **aseq1, **aseq2;
 	int ll1, ll2;
 	int lasti, lastj, imid, jmid=0;
-	float wm = 0.0;   /* int ?????? */
-	float g;
-	float *currentw, *previousw;
+	double wm = 0.0;   /* int ?????? */
+	double g;
+	double *currentw, *previousw;
 #if USE_PENALTY_EX
-	float fpenalty_ex = (float)RNApenalty_ex;
+	double fpenalty_ex = (double)RNApenalty_ex;
 #endif
-//	float fpenalty = (float)penalty;
-	float *wtmp;
+//	double fpenalty = (double)penalty;
+	double *wtmp;
 //	short *ijppt;
 	int *mpjpt;
 //	short **ijp;
 	int *mp;
 	int mpi;
-	float *mjpt, *prept, *curpt;
-	float mi;
-	float *m;
-	float *w1, *w2;
-//	float *match;
-	float *initverticalw;    /* kufuu sureba iranai */
-	float *lastverticalw;    /* kufuu sureba iranai */
+	double *mjpt, *prept, *curpt;
+	double mi;
+	double *m;
+	double *w1, *w2;
+//	double *match;
+	double *initverticalw;    /* kufuu sureba iranai */
+	double *lastverticalw;    /* kufuu sureba iranai */
 	int **intwork;
-	float **floatwork;
+	double **doublework;
 //	short **shortmtx;
 #if STOREWM
-	float **WMMTX;
-	float **WMMTX2;
+	double **WMMTX;
+	double **WMMTX2;
 #endif
-	float *midw;
-	float *midm;
-	float *midn;
+	double *midw;
+	double *midm;
+	double *midn;
 	int lgth1, lgth2;
-	float maxwm = 0.0;
+	double maxwm = 0.0;
 	int *jumpforwi;
 	int *jumpforwj;
 	int *jumpbacki;
@@ -1292,11 +1292,11 @@ static float MSalignmm_rec( int icyc, int jcyc, double *eff1, double *eff2, char
 	int jumpi, jumpj = 0;
 	char *gaps;
 	int ijpi, ijpj;
-	float *ogcp1;
-	float *fgcp1;
-	float *ogcp2;
-	float *fgcp2;
-	float firstm;
+	double *ogcp1;
+	double *fgcp1;
+	double *ogcp2;
+	double *fgcp2;
+	double firstm;
 	int firstmp;
 #if 0
 	static char ttt1[50000];
@@ -1414,7 +1414,7 @@ static float MSalignmm_rec( int icyc, int jcyc, double *eff1, double *eff2, char
 	mp = AllocateIntVec( ll2+2 );
 	gaps = AllocateCharVec( MAX( ll1, ll2 ) + 2 );
 
-	floatwork = AllocateFloatMtx( MAX( ll1, ll2 )+2, nalphabets ); 
+	doublework = AllocateFloatMtx( MAX( ll1, ll2 )+2, nalphabets ); 
 	intwork = AllocateIntMtx( MAX( ll1, ll2 )+2, nalphabets ); 
 
 #if DEBUG
@@ -1438,9 +1438,9 @@ static float MSalignmm_rec( int icyc, int jcyc, double *eff1, double *eff2, char
 	currentw = w1;
 	previousw = w2;
 
-	match_calc( initverticalw, cpmx2+jst, cpmx1+ist, 0, lgth1, floatwork, intwork, 1 );
+	match_calc( initverticalw, cpmx2+jst, cpmx1+ist, 0, lgth1, doublework, intwork, 1 );
 
-	match_calc( currentw, cpmx1+ist, cpmx2+jst, 0, lgth2, floatwork, intwork, 1 );
+	match_calc( currentw, cpmx1+ist, cpmx2+jst, 0, lgth2, doublework, intwork, 1 );
 
 	for( i=1; i<lgth1+1; i++ )
 	{
@@ -1489,7 +1489,7 @@ static float MSalignmm_rec( int icyc, int jcyc, double *eff1, double *eff2, char
 
 		previousw[0] = initverticalw[i-1];
 
-		match_calc( currentw, cpmx1+ist, cpmx2+jst, i, lgth2, floatwork, intwork, 0 );
+		match_calc( currentw, cpmx1+ist, cpmx2+jst, i, lgth2, doublework, intwork, 0 );
 		currentw[0] = initverticalw[i];
 
 		m[0] = ogcp1[i];
@@ -1640,8 +1640,8 @@ static float MSalignmm_rec( int icyc, int jcyc, double *eff1, double *eff2, char
 
 // gyakudp
 
-	match_calc( initverticalw, cpmx2+jst, cpmx1+ist, lgth2-1, lgth1, floatwork, intwork, 1 );
-	match_calc( currentw, cpmx1+ist, cpmx2+jst, lgth1-1, lgth2, floatwork, intwork, 1 );
+	match_calc( initverticalw, cpmx2+jst, cpmx1+ist, lgth2-1, lgth1, doublework, intwork, 1 );
+	match_calc( currentw, cpmx1+ist, cpmx2+jst, lgth1-1, lgth2, doublework, intwork, 1 );
 
 	for( i=0; i<lgth1-1; i++ )
 	{
@@ -1693,7 +1693,7 @@ static float MSalignmm_rec( int icyc, int jcyc, double *eff1, double *eff2, char
 		currentw = wtmp;
 		previousw[lgth2-1] = initverticalw[i+1];
 //		match_calc( currentw, seq1, seq2, i, lgth2 );
-		match_calc( currentw, cpmx1+ist, cpmx2+jst, i, lgth2, floatwork, intwork, 0 );
+		match_calc( currentw, cpmx1+ist, cpmx2+jst, i, lgth2, doublework, intwork, 0 );
 
 		currentw[lgth2-1] = initverticalw[i];
 
@@ -1957,8 +1957,8 @@ static float MSalignmm_rec( int icyc, int jcyc, double *eff1, double *eff2, char
 #if 0
 	for( i=0; i<lgth1; i++ )
 	{
-		float maxpairscore = -9999.9;
-		float tmpscore;
+		double maxpairscore = -9999.9;
+		double tmpscore;
 
 		for( j=0; j<lgth2; j++ )
 		{
@@ -1985,8 +1985,8 @@ static float MSalignmm_rec( int icyc, int jcyc, double *eff1, double *eff2, char
 	}
 	for( j=0; j<lgth2; j++ )
 	{
-		float maxpairscore = -9999.9;
-		float tmpscore;
+		double maxpairscore = -9999.9;
+		double tmpscore;
 
 		for( i=0; i<lgth1; i++ )
 		{
@@ -2134,7 +2134,7 @@ static float MSalignmm_rec( int icyc, int jcyc, double *eff1, double *eff2, char
 	FreeFloatVec( m );
 	FreeIntVec( mp );
 
-	FreeFloatMtx( floatwork );
+	FreeFloatMtx( doublework );
 	FreeIntMtx( intwork );
 
 #if STOREWM
@@ -2157,26 +2157,26 @@ static float MSalignmm_rec( int icyc, int jcyc, double *eff1, double *eff2, char
 
 
 
-float Lalignmm_hmout( char **seq1, char **seq2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, char *sgap1, char *sgap2, char *egap1, char *egap2, float **map )
+double Lalignmm_hmout( char **seq1, char **seq2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, char *sgap1, char *sgap2, char *egap1, char *egap2, double **map )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
 //	int k;
 	int i, j;
 	int ll1, ll2;
 	int lgth1, lgth2;
-	float wm = 0.0;   /* int ?????? */
+	double wm = 0.0;   /* int ?????? */
 	char **mseq1;
 	char **mseq2;
 //	char **mseq;
-	float *ogcp1;
-	float *ogcp2;
-	float *fgcp1;
-	float *fgcp2;
-	float **cpmx1;
-	float **cpmx2;
-	float **gapinfo;
-//	float fpenalty;
-	float fpenalty = (float)RNApenalty;
+	double *ogcp1;
+	double *ogcp2;
+	double *fgcp1;
+	double *fgcp2;
+	double **cpmx1;
+	double **cpmx2;
+	double **gapinfo;
+//	double fpenalty;
+	double fpenalty = (double)RNApenalty;
 	int nglen1, nglen2;
 
 
@@ -2360,24 +2360,24 @@ float Lalignmm_hmout( char **seq1, char **seq2, double *eff1, double *eff2, int
 	return( wm );
 }
 
-float Lalign2m2m_hmout( char **seq1, char **seq2, char **seq1r, char **seq2r, char *dir1, char *dir2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, char *sgap1, char *sgap2, char *egap1, char *egap2, float **map )
+double Lalign2m2m_hmout( char **seq1, char **seq2, char **seq1r, char **seq2r, char *dir1, char *dir2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, char *sgap1, char *sgap2, char *egap1, char *egap2, double **map )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
 //	int k;
 	int i, j;
 	int ll1, ll2;
 	int lgth1, lgth2;
-	float wm = 0.0;   /* int ?????? */
+	double wm = 0.0;   /* int ?????? */
 	char **mseq1;
 	char **mseq2;
-	float *ogcp1;
-	float *ogcp2;
-	float *fgcp1;
-	float *fgcp2;
-	float **cpmx1;
-	float **cpmx2;
-	float **gapinfo;
-	float fpenalty = (float)penalty;
+	double *ogcp1;
+	double *ogcp2;
+	double *fgcp1;
+	double *fgcp2;
+	double **cpmx1;
+	double **cpmx2;
+	double **gapinfo;
+	double fpenalty = (double)penalty;
 	int nglen1, nglen2;
 
 #if 0
