@@ -819,6 +819,7 @@ static void createfgresult( double **gapfresult, int limk, double eff1, double e
 }
 
 static double Atracking( double *lasthorizontalw, double *lastverticalw, 
+						double fpenalty, double fpenalty_ex,
 						char **seq1, char **seq2, 
                         char **mseq1, char **mseq2, 
                         int **ijp, int icyc, int jcyc,
@@ -876,8 +877,8 @@ static double Atracking( double *lasthorizontalw, double *lastverticalw,
 	else
 	{
 #if 1
-		double fpenalty = (double)penalty;
-		double fpenalty_ex = (double)penalty_ex;
+//		double fpenalty = (double)penalty;
+//		double fpenalty_ex = (double)penalty_ex;
 		double g;
 //		reporterr( "in S, lastverticalw[lgth1-1] = %f\n", lastverticalw[lgth1-1] );
 //		reporterr( "in S, lasthorizontalw[lgth2-1] = %f\n", lasthorizontalw[lgth2-1] );
@@ -1066,7 +1067,7 @@ static double Atracking( double *lasthorizontalw, double *lastverticalw,
 	return( wm );
 }
 
-double A__align( double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, int constraint, double *impmatch, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres, int headgp, int tailgp, int firstmem, int calledbyfulltreebase, double **cpmxchild0, double **cpmxchild1, double ***cpmxresult, double orieff1, double orieff2 )
+double A__align( double **n_dynamicmtx, int penalty_l, int penalty_ex_l, char **seq1, char **seq2, double *eff1, double *eff2, int icyc, int jcyc, int alloclen, int constraint, double *impmatch, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres, int headgp, int tailgp, int firstmem, int calledbyfulltreebase, double **cpmxchild0, double **cpmxchild1, double ***cpmxresult, double orieff1, double orieff2 )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
 
@@ -1087,7 +1088,7 @@ double A__align( double **n_dynamicmtx, char **seq1, char **seq2, double *eff1,
 	double *currentw, *previousw;
 //	double fpenalty = (double)penalty;
 #if USE_PENALTY_EX
-	double fpenalty_ex = (double)penalty_ex;
+	double fpenalty_ex = (double)penalty_ex_l;
 #endif
 #if 1
 	double *wtmp;
@@ -1121,7 +1122,7 @@ double A__align( double **n_dynamicmtx, char **seq1, char **seq2, double *eff1,
 	double *gapfreq1pt;
 	static TLS double *gapfreq2;
 	double *gapfreq2pt;
-	double fpenalty = (double)penalty;
+	double fpenalty = (double)penalty_l;
 	double fpenalty_shift = (double)penalty_shift;
 	double *fgcp2pt;
 	double *ogcp2pt;
@@ -2050,7 +2051,7 @@ fprintf( stderr, "\n" );
 	else
 	{
 //		wmo = Atracking( currentw, lastverticalw, seq1, seq2, mseq1, mseq2, ijp, icyc, jcyc, tailgp, warpis, warpjs, warpbase, &ngap1, &ngap2, reuseprofiles, eff1, eff2, cpmxresult, cpmx1pt, cpmx2pt, gapfreq1pt, gapfreq2pt, ogcp1opt, ogcp2opt, fgcp1opt, fgcp2opt, orieff1, orieff2, (cpmx1pt!=cpmx1), (cpmx2pt!=cpmx2) );
-		wmo = Atracking( currentw, lastverticalw, seq1, seq2, mseq1, mseq2, ijp, icyc, jcyc, tailgp, warpis, warpjs, warpbase, &ngap1, &ngap2, reuseprofiles, &gt1, &gt2 );
+		wmo = Atracking( currentw, lastverticalw, fpenalty, fpenalty_ex, seq1, seq2, mseq1, mseq2, ijp, icyc, jcyc, tailgp, warpis, warpjs, warpbase, &ngap1, &ngap2, reuseprofiles, &gt1, &gt2 );
 		if( !tailgp ) wm = wmo;
 	}
 
@@ -2194,7 +2195,7 @@ double A__align_gapmap( char **seq1, char **seq2, double *eff1, double *eff2, in
 }
 
 
-double A__align_variousdist( int **which, double ***matrices, double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, double *eff2, double **eff1s, double **eff2s, int icyc, int jcyc, int alloclen, int constraint, double *impmatch, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres, int headgp, int tailgp )
+double A__align_variousdist( int **which, double ***matrices, double **n_dynamicmtx, int penalty_l, int penalty_ex_l, char **seq1, char **seq2, double *eff1, double *eff2, double **eff1s, double **eff2s, int icyc, int jcyc, int alloclen, int constraint, double *impmatch, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres, int headgp, int tailgp )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
 
@@ -2211,7 +2212,7 @@ double A__align_variousdist( int **which, double ***matrices, double **n_dynamic
 	double *currentw, *previousw;
 //	double fpenalty = (double)penalty;
 #if USE_PENALTY_EX
-	double fpenalty_ex = (double)penalty_ex;
+	double fpenalty_ex = (double)penalty_ex_l;
 #endif
 #if 1
 	double *wtmp;
@@ -2240,7 +2241,7 @@ double A__align_variousdist( int **which, double ***matrices, double **n_dynamic
 	static TLS int orlgth1 = 0, orlgth2 = 0;
 	static TLS double *gapfreq1;
 	static TLS double *gapfreq2;
-	double fpenalty = (double)penalty;
+	double fpenalty = (double)penalty_l;
 	double fpenalty_shift = (double)penalty_shift;
 	double *fgcp2pt;
 	double *ogcp2pt;
@@ -3041,7 +3042,7 @@ fprintf( stderr, "\n" );
 	else
 	{
 //		Atracking( currentw, lastverticalw, seq1, seq2, mseq1, mseq2, ijp, icyc, jcyc, tailgp, warpis, warpjs, warpbase, &ngap1, &ngap2, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0.0, 0.0, 1, 1 ); // NULL x 11 ha atode awaseru.
-		wmo = Atracking( currentw, lastverticalw, seq1, seq2, mseq1, mseq2, ijp, icyc, jcyc, tailgp, warpis, warpjs, warpbase, &ngap1, &ngap2, 0, NULL, NULL);
+		wmo = Atracking( currentw, lastverticalw, fpenalty, fpenalty_ex, seq1, seq2, mseq1, mseq2, ijp, icyc, jcyc, tailgp, warpis, warpjs, warpbase, &ngap1, &ngap2, 0, NULL, NULL);
 		if( !tailgp ) wm = wmo;
 	}
 
