@@ -21,8 +21,8 @@ void unknown_n( char *out, char *in )
 		else
 			*out = 'N';
 
-		*out++;
-		*in++;
+		out++;
+		in++;
 	}
 	*out = 0;
 }
@@ -46,7 +46,7 @@ static void readcontrafold( FILE *fp, RNApair **pairprob, int length )
 	char *pt;
 	int i;
 	int left, right;
-	float prob;
+	double prob;
 
 	pairnum = (int *)calloc( length, sizeof( int ) );
 	for( i=0; i<length; i++ ) pairnum[i] = 0;
@@ -71,7 +71,7 @@ static void readcontrafold( FILE *fp, RNApair **pairprob, int length )
 		{
 			pt++;
 //			fprintf( stderr, "pt=%s\n", pt );
-			sscanf( pt, "%d:%f", &right, &prob );
+			sscanf( pt, "%d:%lf", &right, &prob );
 			right--;
 
 //			fprintf( stderr, "%d-%d, %f\n", left, right, prob );
@@ -155,7 +155,7 @@ int main( int argc, char *argv[] )
 	RNApair *pairprobpt;
 	RNApair *pt;
 	int *alnpairnum;
-	float prob;
+	double prob;
 	int adpos;
 
 	arguments( argc, argv );
@@ -300,7 +300,7 @@ int main( int argc, char *argv[] )
 
 	for( i=0; i<nlenmax; i++ ) for( pairprobpt=alnpairprob[i]; pairprobpt->bestpos!=-1; pairprobpt++ )
 	{
-		pairprobpt->bestscore /= (float)njob;
+		pairprobpt->bestscore /= (double)njob;
 		left = i;
 		right = pairprobpt->bestpos;
 		prob = pairprobpt->bestscore;
