@@ -14,7 +14,7 @@ void arguments( int argc, char *argv[] )
             {
 				case 'i':
 					inputfile = *++argv;
-					fprintf( stderr, "inputfile = %s\n", inputfile );
+//					fprintf( stderr, "inputfile = %s\n", inputfile );
 					--argc;
 					goto nextoption;
                 default:
@@ -38,6 +38,7 @@ int main( int argc, char *argv[] )
 {
 	FILE *infp;
 	int nlenmin;
+	double nfreq;
 
 	arguments( argc, argv );
 
@@ -54,8 +55,10 @@ int main( int argc, char *argv[] )
 		infp = stdin;
 
 	dorp = NOTSPECIFIED;
-	getnumlen_nogap( infp, &nlenmin );
+	getnumlen_nogap_countn( infp, &nlenmin, &nfreq );
 
-	fprintf( stdout, "%d x %d - %d %c\n", njob, nlenmax, nlenmin, dorp );
+	fprintf( stdout, "%d x %d - %d %c nfreq=%f\n", njob, nlenmax, nlenmin, dorp, nfreq );
+
+	fclose( infp );
 	return( 0 );
 }
