@@ -1,12 +1,12 @@
-#include <stdio.h>
-#include "dp.h"
 #include "mltaln.h"
+#include "dp.h"
 
 int TLS commonAlloc1 = 0;
 int TLS commonAlloc2 = 0;
 int TLS **commonIP = NULL;
 int TLS **commonJP = NULL;
 int nthread = 1;
+int nthreadpair = 1;
 int randomseed = 0;
 int parallelizationstrategy = BAATARI1;
 
@@ -131,6 +131,8 @@ double sueff_global = SUEFF;
 double lenfaca, lenfacb, lenfacc, lenfacd;
 int maxl, tsize;
 
+
+
 void initglobalvariables()
 {
 	commonAlloc1 = 0;
@@ -163,3 +165,11 @@ void initglobalvariables()
 	
 	gmsg = 0;
 }
+
+// for usetmpfile
+int compacttree = 0;
+int lhlimit = INT_MAX;
+int specifictarget = 0;
+int nadd = 0; // <- static in tbfast.c, pairlocalalign.c
+int usenaivescoreinsteadofalignmentscore = 0;
+int nthreadreadlh = 1;
