@@ -159,7 +159,7 @@ void treebase( char **name, int nlen[M], char **seq, char **aseq, char **mseq1,
 	int i, j, l;
 	int clus1, clus2;
 	int s1, s2, r1, r2;
-	float pscore;
+	double pscore;
 	static char *indication1, *indication2;
 	static char **name1, **name2;
 	static double **partialmtx = NULL;
