@@ -37,7 +37,7 @@
 
 
 
-#define VERSION "7.429"
+#define VERSION "7.453"
 #define SHOWVERSION reporterr( "%s (%s) Version " VERSION "\nalg=%c, model=%s, amax=%3.1f\n%d thread(s)\n\n", progName( argv[0] ), (dorp=='d')?"nuc":((nblosum==-2)?"text":"aa"), alg, modelname, specificityconsideration, nthread )
 
 #define FFT_THRESHOLD  80
@@ -321,7 +321,16 @@ typedef struct _pairnum
 	int n1;
 } Pairnum;
 
-
+typedef struct _extanch
+{
+	int i;
+	int j;
+	int starti;
+	int endi;
+	int startj;
+	int endj;
+	int score;
+} ExtAnch;
 
 #include "fft.h"
 #include "dp.h"
