@@ -14,13 +14,10 @@ static int stdout_align;
 static int stdout_dist;
 static int store_localhom;
 static int store_dist;
-static int nadd;
 static int laste;
 static int lastm;
 static int lastsubopt;
 static int lastonce;
-static int usenaivescoreinsteadofalignmentscore;
-static int specifictarget;
 
 typedef struct _lastres
 {
@@ -3210,10 +3207,22 @@ int pairlocalalign( int ngui, int lgui, char **namegui, char **seqgui, double **
 
 
 
-	for( i=0; i<njob; i++ ) 
+	if( dorp == 'p' && scoremtx == 1 && nblosum > 0 ) // protein, not text.  hitsuyou?
 	{
-		gappick0( bseq[i], seq[i] );
-		thereisxineachseq[i] = removex( dseq[i], bseq[i] );
+		for( i=0; i<njob; i++ ) 
+		{
+			gappick0( bseq[i], seq[i] );
+			thereisxineachseq[i] = removex( dseq[i], bseq[i] );
+		}
+	}
+	else // text, dna
+	{
+		for( i=0; i<njob; i++ ) 
+		{
+			gappick0( bseq[i], seq[i] );
+			strcpy( dseq[i], bseq[i] );
+			thereisxineachseq[i] = 0;
+		}
 	}
 
 	pairalign( name, nlen, bseq, aseq, dseq, thereisxineachseq, mseq1, mseq2, alloclen, lastresx, distancemtx, localhomtable, ngui );
@@ -3306,3 +3315,207 @@ int pairlocalalign( int ngui, int lgui, char **namegui, char **seqgui, double **
 	return( 0 );
 }
 
+void pairalign_node( int njob, int nlenmax, char **name, char **seq, int ***topol, double **len, Treedep *dep, int treegiven, int treeout ) // used by nodepair
+{
+/* test */
+	double *selfscore;
+//	int ***topol;
+//	double **len;
+//	Treedep *dep;
+	char *fn;
+	int i, ntarget;
+	int *uselh;
+	int *nfilesfornode;
+	char **bseq;
+	char **dseq;
+	int alloclen = nlenmax * 2;
+	int alignmentlength;
+	FILE *fp;
+
+	bseq = AllocateCharMtx( njob, alloclen+10 );
+	dseq = AllocateCharMtx( njob, alloclen+10 );
+	uselh = calloc( njob, sizeof( int ) );
+	nfilesfornode = calloc( njob-1, sizeof( int ) );
+
+	for( i=0; i<njob; i++ ) 
+	{
+		gappick0( bseq[i], seq[i] );
+		removex( dseq[i], bseq[i] );
+	}
+
+	if( nadd )
+	{
+		if( addprofile )
+		{
+			reporterr( "--addprofile is not yet supported\n" );
+			exit( 1 );
+		}
+		alignmentlength = strlen( seq[0] );
+		for( i=njob-nadd-1; i>0; i-- )
+		{
+			if( alignmentlength != strlen( seq[i] ) )
+			{
+				fprintf( stderr, "#################################################################################\n" );
+				fprintf( stderr, "# ERROR!                                                                       \n" );
+				fprintf( stderr, "# For the --add option, the original%4d sequences must be aligned              \n", njob-nadd );
+				fprintf( stderr, "#################################################################################\n" );
+				exit( 1 );
+			}
+		}
+	}
+
+	if( specifictarget )
+	{
+		reporterr( "specifictarget\n" );
+
+		ntarget = 0;
+		for( i=0; i<njob; i++ )
+		{
+			uselh[i] = 0;
+			if( !strncmp( name[i]+1, "_focus_", 7 ) )
+			{
+				uselh[i] = 1;
+				ntarget++;
+			}
+		}
+
+		if( ntarget == 0 )
+		{
+			reporterr( "\n\nAdd '>_focus_' to the title lines of the sequences to be focused on.\n\n" );
+			exit( 1 );
+		}
+		else
+		{
+			reporterr( "nfocus = %d \n", ntarget );
+		}
+	}
+	else
+	{
+		ntarget = njob;
+//		targetmap = calloc( njob, sizeof( int ) );
+//		targetmapr = calloc( njob, sizeof( int ) );
+
+//		for( i=0; i<njob; i++ ) targetmap[i] = i;
+//		if( alg != 'Y' && alg != 'r' )
+//			stringshuffle( targetmap, njob );
+
+#if 0
+		for( i=0; i<njob; i++ ) uselh[i] = 1;
+#else
+
+		char *tmpseq;
+		Lennum *tmpstr;
+		tmpseq = (char *)calloc( nlenmax+1, sizeof( char ) );
+		tmpstr = (Lennum *)calloc( njob, sizeof( Lennum ) );
+		for( i=0; i<njob; i++ )
+		{
+			gappick0( tmpseq, seq[i] );
+			tmpstr[i].len = strlen( tmpseq );
+			tmpstr[i].num = i;
+//			reporterr( "nlen[%d] = %d\n", i, nlen[i] );
+//			reporterr( "strlen = %d\n", strlen( seq[i] ) );
+//			reporterr( "seq = %s\n", seq[i] );
+		}
+
+		limitlh( uselh, tmpstr, njob, lhlimit );
+
+		free( tmpseq );
+		free( tmpstr );
+#endif
+
+//		for( i=0; i<njob; i++ )
+//			reporterr( "targetmap[%d] = %d\n", i, targetmap[i] );
+	}
+
+//	for( i=0; i<njob; i++ ) reporterr( "uselh[%d] = %d\n", i, uselh[i] );
+
+
+	selfscore = AllocateDoubleVec( njob );
+	fn = calloc( 100, sizeof( char ) );
+//	topol = AllocateIntCub( njob, 2, 0 );
+//	len = AllocateFloatMtx( njob, 2 );
+//	dep = (Treedep *)calloc( njob, sizeof( Treedep ) );
+	system( "rm -rf hat3dir" ); // toriaezu
+	system( "mkdir hat3dir" ); // toriaezu
+
+	for( i=0; i<njob-1; i+=HAT3NODEBLOCK ) 
+	{
+		sprintf( fn, "mkdir \"hat3dir/%d-\"", i ); // windows de slash wo tsukau tame niju in-youfu hitsuyou
+		system( fn );
+	}
+	free( fn );
+
+	for( i=0; i<njob; i++ ) selfscore[i] = (double)naivepairscore11( seq[i], seq[i], 0.0 ); // dseq??
+
+
+
+#if 0
+	remove( "hat1node" );
+	if( (fd1 = open("hat1node",O_RDWR|O_CREAT,0600)) == -1)
+	{
+		reporterr( "failed to open hat1node\n" );
+		exit( 1 );
+	}
+
+	remove( "hat0node" );
+	if( (fd0 = open("hat0node",O_RDWR|O_CREAT,0600)) == -1)
+	{
+		reporterr( "failed to open hat0node\n" );
+		exit( 1 );
+	}
+
+	remove( "hat2node" ); // test only. ato de kesu.
+	if( (fd2 = open("hat2node",O_RDWR|O_CREAT,0600)) == -1)
+	{
+		reporterr( "failed to open hat2node\n" );
+		exit( 1 );
+	}
+#endif
+
+//	reporterr( "Call compacttreedpdist here.\n" );
+//	compacttreedpdist( njob, seq, dseq, selfscore, topol, len, name, dep, 1, 1, 2*nlenmax+1, uselh ); // dame
+//	compacttreedpdist( njob, bseq, dseq, selfscore, topol, len, name, dep, 1, 2*nlenmax+1, uselh, nfilesfornode, treegiven );
+	compacttreedpdist( njob, bseq, dseq, selfscore, topol, len, name, dep, treeout, 2*nlenmax+1, uselh, nfilesfornode, treegiven );
+
+
+	fp = fopen( "hat3dir/tree", "wb" ); // window no tame wb
+	treeout_bin( fp, njob, topol, len, dep, nfilesfornode );
+	fclose( fp );
+
+	fp = fopen( "hat3dir/uselh", "wb" ); // nenno tame 
+	uselhout( fp, njob, uselh );
+	fclose( fp );
+
+#if 0
+	if( close( fd0 ) != 0 )
+	{
+		reporterr( "error in close( hat0node )\n" );
+		exit( 1 );
+	}
+
+	if( close( fd1 ) != 0 )
+	{
+		reporterr( "error in close( hat1node )\n" );
+		exit( 1 );
+	}
+
+	if( close( fd2 ) != 0 )
+	{
+		reporterr( "error in close( hat2node )\n" );
+		exit( 1 );
+	}
+#endif
+
+//	FreeFloatMtx( len );
+//	free( dep );
+	free( selfscore );
+//	free( targetmap );
+//	free( targetmapr );
+	free( uselh );
+	free( nfilesfornode );
+	FreeCharMtx( bseq );
+	FreeCharMtx( dseq );
+//	FreeIntCub( topol ); topol = NULL; // koko?
+
+/* test owari */
+}
