@@ -59,6 +59,7 @@ void readereg( FILE *regfp, int **regtable, char **revtable, int *outtable, int
 	char gett[1000];
 	int j;
 	int mem;
+	char cmem;
 	char reg[5][100];
 	char out[100];
 	int startpos, endpos;
@@ -66,18 +67,22 @@ void readereg( FILE *regfp, int **regtable, char **revtable, int *outtable, int
 	*noutpt = 0;
 	*loutpt = 0;
 	fgets( gett, 999, regfp );
-	sscanf( gett, "%c %s %s %s %s %s", &mem, reg[0], reg[1], reg[2], reg[3], reg[4] );
-	if( mem != 'e' )
+	reg[0][0] = reg[1][0] = reg[2][0] = reg[3][0] = reg[4][0] = 'n';
+	reg[0][1] = reg[1][1] = reg[2][1] = reg[3][1] = reg[4][1] = 0;
+	sscanf( gett, "%c %s %s %s %s %s", &cmem, reg[0], reg[1], reg[2], reg[3], reg[4] );
+	if( cmem != 'e' )
 	{
 		fprintf( stderr, "Format error\n" );
 		exit( 1 );
 	}
 	for( j=0; j<5; j++ )
 	{
+//		reporterr( "reg[j]=%s\n", reg[j] );
 		sscanf( reg[j], "%d-%d-%c", regtable[0]+(j*2), regtable[0]+(j*2)+1, revtable[0]+j );
 		fprintf( stderr, "%d %d-%d\n", 0, regtable[0][j*2], regtable[0][j*2+1] );
 		startpos = regtable[0][j*2];
 		endpos   = regtable[0][j*2+1];
+//		reporterr( "startpod=%d, endpos=%d, *loutpt=%d\n", startpos, endpos, *loutpt );
 		if( startpos > endpos )
 		{
 			endpos   = regtable[0][j*2];
