@@ -27,6 +27,7 @@ void arguments( int argc, char *argv[] )
 
 	seedoffset = 0;
 	inputfile = NULL;
+	dorp = NOTSPECIFIED;
 
     while( --argc > 0 && (*++argv)[0] == '-' )
 	{
@@ -35,7 +36,7 @@ void arguments( int argc, char *argv[] )
             switch( c )
             {
 				case 'o':
-					seedoffset = atoi( *++argv );
+					seedoffset = myatoi( *++argv );
 					fprintf( stderr, "seedoffset = %d\n", seedoffset );
 					--argc;
 					goto nextoption;
@@ -44,6 +45,12 @@ void arguments( int argc, char *argv[] )
 					fprintf( stderr, "inputfile = %s\n", inputfile );
 					--argc;
 					goto nextoption;
+				case 'D':
+					dorp = 'd';
+					break;
+				case 'P':
+					dorp = 'p';
+					break;
                 default:
                     fprintf( stderr, "illegal option %c\n", c );
                     argc = 0;
@@ -87,7 +94,7 @@ int main( int argc, char *argv[] )
 		infp = stdin;
 
 
-	dorp = NOTSPECIFIED;
+//	dorp = NOTSPECIFIED;
 	getnumlen_casepreserve( infp, &nlenmin );
 
 	fprintf( stderr, "%d x %d - %d %c\n", njob, nlenmax, nlenmin, dorp );
@@ -125,7 +132,7 @@ int main( int argc, char *argv[] )
 	}
 	else
 	{
-		usual = "ATGCUatgcu-";
+		usual = "ATGCUatgcuBDHKMNRSVWYXbdhkmnrsvwyx-";
 		replace_unusual( njob, seq, usual, 'n', tolower );
 	}
 	
