@@ -517,7 +517,7 @@ int fastconjuction_target( int *memlist, char **seq, char **aseq, double *peff,
 #endif
 
 
-int fastconjuction_noname( int *memlist, char **seq, char **aseq, double *peff, double *eff, char *d, double mineff  )
+int fastconjuction_noname( int *memlist, char **seq, char **aseq, double *peff, double *eff, char *d, double mineff, double *oritotal  )
 {
 	int m, k, dln;
 	char b[B];
@@ -547,10 +547,11 @@ int fastconjuction_noname( int *memlist, char **seq, char **aseq, double *peff,
 
 		total += peff[k];
 	}
+	if( oritotal ) *oritotal = total;
 #if 1
 	for( m=0; m<k; m++ )
 	{
-//		fprintf( stderr, "Apr17   peff[%d] = %f\n", m, peff[m] );
+//		fprintf( stderr, "Apr17   peff[%d] = %20.10f\n", m, peff[m] );
 		peff[m] /= total;
 	}
 #endif
@@ -1041,6 +1042,51 @@ int fastshrinklocalhom( int *mem1, int *mem2, LocalHom **localhom, LocalHom ***l
 	return( 0 );
 }
 
+int fastshrinklocalhom_half_seed( int *mem1, int *mem2, int nseed, int *posinlsh1, int *posinlsh2, LocalHom **localhom, LocalHom ***localhomshrink )
+{
+	int k1, k2, sk1, sk2;
+	int *intpt1, *intpt2;
+
+	for( intpt1=mem1, k1=0, sk1=0; *intpt1!=-1; intpt1++, k1++ )
+	{
+		if( *intpt1>=nseed ) posinlsh1[k1] = -1;
+		else posinlsh1[k1] = sk1++;
+	}
+	for( intpt2=mem2, k2=0, sk2=0; *intpt2!=-1; intpt2++, k2++ )
+	{
+		if( *intpt2>=nseed ) posinlsh2[k2] = -1;
+		else posinlsh2[k2] = sk2++;
+	}
+	
+	for( intpt1=mem1, sk1=0; *intpt1!=-1; intpt1++ )
+	{
+		if( *intpt1>=nseed ) continue;
+		for( intpt2=mem2, sk2=0; *intpt2!=-1; intpt2++ )
+		{
+			if( *intpt2>=nseed ) continue;
+			if( *intpt1 < *intpt2 )
+			{
+				if( localhom[*intpt1][*intpt2-*intpt1].opt == -1 )
+					localhomshrink[sk1][sk2] = NULL;
+				else
+					localhomshrink[sk1][sk2] = localhom[*intpt1]+*intpt2-*intpt1;
+			}
+			else
+			{
+				if( localhom[*intpt2][*intpt1-*intpt2].opt == -1 )
+					localhomshrink[sk1][sk2] = NULL;
+				else
+					localhomshrink[sk1][sk2] = localhom[*intpt2]+*intpt1-*intpt2;
+			}
+
+//			if( localhomshrink[k1][k2] != NULL )
+//				printf( "ori localhomshrink[%d][%d].opt = %f, .importance=%f\n", k1, k2, localhomshrink[k1][k2]->opt, localhomshrink[k1][k2]->importance );
+			sk2++;
+		}
+		sk1++;
+	}
+	return( 0 );
+}
 
 int fastshrinklocalhom_half( int *mem1, int *mem2, LocalHom **localhom, LocalHom ***localhomshrink )
 {
