@@ -223,7 +223,7 @@ void treeCnv( Node *stopol, int locnseq, int ***topol, double **len, double **bw
 
 	if     ( stopol[locnseq-2].children[0] == &stopol[locnseq-3] ) i = 1;
 	else if( stopol[locnseq-2].children[1] == &stopol[locnseq-3] ) i = 0;
-	else ErrorExit( "?\n" );
+	else ErrorExit( "ERROR in stopol ?\n" );
 
 	stopol[locnseq-3].length[2] = len[locnseq-2][0] + len[locnseq-2][1];
 	stopol[locnseq-3].weightptr[2] = &bw[locnseq-2][0];
